pub struct ForeignKeyDefinition {
pub name: String,
pub column: String,
pub referenced_table: String,
pub referenced_column: String,
pub on_delete: String,
pub on_update: String,
}Fields
name: Stringcolumn: Stringreferenced_table: Stringreferenced_column: Stringon_delete: Stringon_update: StringTrait Implementations
Sourceimpl Clone for ForeignKeyDefinition
impl Clone for ForeignKeyDefinition
Sourcefn clone(&self) -> ForeignKeyDefinition
fn clone(&self) -> ForeignKeyDefinition
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ForeignKeyDefinition
impl Debug for ForeignKeyDefinition
Sourceimpl Default for ForeignKeyDefinition
impl Default for ForeignKeyDefinition
Sourceimpl<'py> IntoPyObject<'py> for ForeignKeyDefinition
impl<'py> IntoPyObject<'py> for ForeignKeyDefinition
Sourcetype Target = ForeignKeyDefinition
type Target = ForeignKeyDefinition
The Python output type
Sourcetype Output = Bound<'py, <ForeignKeyDefinition as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <ForeignKeyDefinition as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PartialEq for ForeignKeyDefinition
impl PartialEq for ForeignKeyDefinition
Sourceimpl PyClass for ForeignKeyDefinition
impl PyClass for ForeignKeyDefinition
Sourceimpl PyClassImpl for ForeignKeyDefinition
impl PyClassImpl for ForeignKeyDefinition
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<ForeignKeyDefinition>
type ThreadChecker = SendablePyClass<ForeignKeyDefinition>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyTypeInfo for ForeignKeyDefinition
impl PyTypeInfo for ForeignKeyDefinition
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.impl DerefToPyAny for ForeignKeyDefinition
impl Eq for ForeignKeyDefinition
impl ExtractPyClassWithClone for ForeignKeyDefinition
impl StructuralPartialEq for ForeignKeyDefinition