pub struct IndexDefinition {
pub name: String,
pub columns: Vec<String>,
pub is_unique: bool,
pub is_full_text: bool,
}Fields
name: Stringcolumns: Vec<String>is_unique: boolis_full_text: boolTrait Implementations
Sourceimpl Clone for IndexDefinition
impl Clone for IndexDefinition
Sourcefn clone(&self) -> IndexDefinition
fn clone(&self) -> IndexDefinition
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IndexDefinition
impl Debug for IndexDefinition
Sourceimpl Default for IndexDefinition
impl Default for IndexDefinition
Sourceimpl<'py> IntoPyObject<'py> for IndexDefinition
impl<'py> IntoPyObject<'py> for IndexDefinition
Sourcetype Target = IndexDefinition
type Target = IndexDefinition
The Python output type
Sourcetype Output = Bound<'py, <IndexDefinition as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <IndexDefinition as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PartialEq for IndexDefinition
impl PartialEq for IndexDefinition
Sourceimpl PyClass for IndexDefinition
impl PyClass for IndexDefinition
Sourceimpl PyClassImpl for IndexDefinition
impl PyClassImpl for IndexDefinition
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<IndexDefinition>
type ThreadChecker = SendablePyClass<IndexDefinition>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyTypeInfo for IndexDefinition
impl PyTypeInfo for IndexDefinition
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.impl DerefToPyAny for IndexDefinition
impl Eq for IndexDefinition
impl ExtractPyClassWithClone for IndexDefinition
impl StructuralPartialEq for IndexDefinition